@@ -1,3 +1,6 @@
+time_now <- function()
+    proc.time()[["elapsed"]]
+
 token_dispenser <- function(n, period, precision = 60) {
     assert_that(is.count(n))
     assert_that(is.number(period))
@@ -6,17 +9,16 @@ token_dispenser <- function(n, period, precision = 60) {
     # So period (entered in seconds) is converted to period * precision
     period <- period * precision
 
-    init_time <- ceiling(as.numeric(Sys.time()) * precision)
+    init_time <- ceiling(time_now() * precision)
 
     tokens <- fixed_queue(n)
     replicate(n, push(tokens, init_time))
 
     request <- function() {
-        now <- floor(as.numeric(Sys.time()) * precision)
+        now <- floor(time_now() * precision)
         token <- front(tokens)
         if (now > token) {
             pop(tokens)
-            push(tokens, ceiling(as.numeric(Sys.time()) * precision) + period)
             return(TRUE)
         }
 
@@ -24,13 +26,29 @@ token_dispenser <- function(n, period, precision = 60) {
         time_to_wait <- (token - now) / precision
         signalCondition(rate_limit_exception(time_to_wait))
     }
-    structure(request, class = "token_dispenser")
+
+    deposit <- function() {
+        push(tokens, ceiling(time_now() * precision) + period)
+        return(TRUE)
+    }
+
+    dispatch <- function(action) {
+        switch(action,
+               "request" = request,
+               "deposit" = deposit)
+    }
+
+    structure(dispatch, class = "token_dispenser")
 }
 
 request <- function(x, policy = wait) {
     tryCatch(
-        x(),
+        x("request")(),
         rate_limit_exception = function(e) policy(x, e),
         error = function(e) stop(e$message, call. = FALSE)
     )
 }
+
+deposit <- function(x) {
+    x("deposit")()
+}
